==> POCSdk-1.0.52-sources.jar: com/xdja/poc/sdk/config/UserConfig.java <==
package com.xdja.poc.sdk.config;

import com.xdja.poc.sdk.bean.POCMemberInfo;

import java.util.HashMap;
import java.util.Map;

/**
 * janus-gateway-android-master
 * 功能
 * 描述
 * created by Wwq : 2018/9/4
 */

public class UserConfig {
    public static final int VIEW_STTAUS_NORMAL = 0;//正常显示view
    public static final int VIEW_STTAUS_EMPTY = 1;//空页面显示
    public static final int VIEW_STTAUS_ERROR = 2;//错误页面显示
    public static final String CALL_WAITING_TIME = "poc_call_waiting_time";
    public static final String APP_ICON = "app_icon";
    public static final String NOTIFICATION_ICON = "notification_icon";
    public static final String ROUTER_SCHEME = "router_scheme";
    public static final String APP_NAME = "app_name";
    public static final String MAX_MEMBER_COUNT = "max_member_count";
    public static final String IS_SHOW_NOTIFICATION="is_show_notification";
    public static final String IS_SHOW_HOME_TOAST="is_show_home_toast";
    public static final String TOAST_TALKING_DESC="toast_talking_desc";
    public static final String AN_TONG_PACKNAME="com.xdja.poc";
    public static final String PTT_KEY_CODE="ptt_key_code";
    public static final String POC_IS_SAVE_RECORD="poc_is_save_record";
    public static final String POC_IS_SHOW_HISTORY_RECORD_ENTER="poc_is_show_history_record_enter";
    public static final String POC_SELF_SPEAKING_TIPS="poc_self_speaking_tips";
    public static  Map<String,Map<String,POCMemberInfo>> userNameMap=new HashMap<>();




    //Preference  key
    public static final String LOGIN_ACCOUNT = "login_account";
    public static final String LOGIN_PWD = "login_pwd";
    public final static String PREF_KEY_TOKEN = "pref_key_token";
    public final static String PREF_KEY_COMPANY_CODE = "pref_key_company_code";

    //uerInfo
    public final static String USER_INFO_NAME = "pref_key_userinfo_name";
    public final static String USER_INFO_ICON = "pref_key_userinfo_icon";
    public final static String USER_INFO_DEP_CODE = "pref_key_userinfo_dep_code";



    public static final String COMPANY_CODE = "companyCode";
    public static final String AUTHORIZATION = "authorization";


    //临时频道最大人数
    public static final int MAX_COUNT_GROUP = 29;
    public static final String MAX_CHANNEL_COUNT = "max_channel_count";
    public static final String UN_DEFINE="undefined";

}

==> POCSdk-1.0.80-sources.jar: com/xdja/poc/sdk/config/UserConfig.java <==
package com.xdja.poc.sdk.config;

import com.xdja.poc.sdk.bean.POCMemberInfo;

import java.util.HashMap;
import java.util.Map;

/**
 * janus-gateway-android-master
 * 功能
 * 描述
 * created by Wwq : 2018/9/4
 */

public class UserConfig {
    public static final int VIEW_STTAUS_NORMAL = 0;//正常显示view
    public static final int VIEW_STTAUS_EMPTY = 1;//空页面显示
    public static final int VIEW_STTAUS_ERROR = 2;//错误页面显示
    public static final String CALL_WAITING_TIME = "poc_call_waiting_time";
    public static final String APP_ICON = "app_icon";
    public static final String NOTIFICATION_ICON = "notification_icon";
    public static final String ROUTER_SCHEME = "router_scheme";
    public static final String APP_NAME = "app_name";
    public static final String MAX_MEMBER_COUNT = "max_member_count";
    public static final String IS_SHOW_NOTIFICATION = "is_show_notification";
    public static final String IS_SHOW_HOME_TOAST = "is_show_home_toast";
    public static final String TOAST_TALKING_DESC = "toast_talking_desc";
    public static final String AN_TONG_PACKNAME = "com.xdja.poc";
    public static final String PTT_KEY_CODE = "ptt_key_code";
    public static final String DEVICE_IMEI="device_imei";
    public static final String POC_IS_SAVE_RECORD = "poc_is_save_record";
    public static final String POC_IS_SHOW_HISTORY_RECORD_ENTER = "poc_is_show_history_record_enter";
    public static final String POC_SELF_SPEAKING_TIPS = "poc_self_speaking_tips";
    public static Map<String, Map<String, POCMemberInfo>> userNameMap = new HashMap<>();


    //Preference  key
    public static final String LOGIN_ACCOUNT = "login_account";
    public static final String LOGIN_PWD = "login_pwd";
    public final static String PREF_KEY_TOKEN = "pref_key_token";
    public final static String PREF_KEY_COMPANY_CODE = "pref_key_company_code";

    //uerInfo
    public final static String USER_INFO_NAME = "pref_key_userinfo_name";
    public final static String USER_INFO_ICON = "pref_key_userinfo_icon";
    public final static String USER_INFO_DEP_CODE = "pref_key_userinfo_dep_code";


    public static final String COMPANY_CODE = "companyCode";
    public static final String AUTHORIZATION = "authorization";


    //临时频道最大人数
    public static final int MAX_COUNT_GROUP = 29;
    public static final String MAX_CHANNEL_COUNT = "max_channel_count";
    public static final String UN_DEFINE = "undefined";

}
